defmodule DecentralisedBookIndexWeb.UserLive.Show do
  use DecentralisedBookIndexWeb, :live_view

  @impl true
  def render(assigns) do
    ~H"""
    <.header class="flex-col lg:flex-row">
      {@user.email}

      <:actions>
        <.link navigate={~p"/users/#{@user}/edit"}>
          <.edit_button>
            Edit Role
          </.edit_button>
        </.link>
      </:actions>
    </.header>

    <div>
      <dl>
        <dt class="mb-2 font-semibold leading-none text-gray-900 dark:text-white">Email</dt>
        <dd class="mb-4 font-light text-gray-500 sm:mb-5 dark:text-gray-400">{@user.email}</dd>
      </dl>
      <dl>
        <dt class="mb-2 font-semibold leading-none text-gray-900 dark:text-white">Role</dt>
        <dd class="mb-4 font-light text-gray-500 sm:mb-5 dark:text-gray-400">{@user.role}</dd>
      </dl>
    </div>

    <.back navigate={~p"/users"}>Back to users</.back>
    """
  end

  @impl true
  def mount(_params, _session, socket) do
    {:ok, socket}
  end

  @impl true
  def handle_params(%{"id" => id}, _, socket) do
    {:noreply,
     socket
     |> assign(:page_title, page_title(socket.assigns.live_action))
     |> assign(
       :user,
       Ash.get!(DecentralisedBookIndex.Accounts.User, id, actor: socket.assigns.current_user)
     )}
  end

  defp page_title(:show), do: "Show User"
  defp page_title(:edit), do: "Edit User"
end
